pub struct AdaDelta {
pub lr: Array,
pub rho: Array,
pub eps: Array,
pub state: State<(Array, Array)>,
}Expand description
The AdaDelta optimizer with a learning rate.
The default rho is 0.9, matching Python MLX. Earlier mlx-rs releases used 0.99.
Please refer to the original paper for more details:
[1]: Zeiler, M.D., 2012. ADADELTA: an adaptive learning rate method. arXiv preprint arXiv:1212.5701.
Fields
lr: ArrayThe learning rate
rho: ArrayThe coefficient used for computing a running average of squared gradients. Defaults to
AdaDelta::DEFAULT_RHO (0.9, matching Python MLX).
eps: ArrayThe epsilon added to the denominator to improve numerical stability. Default to
AdaDelta::DEFAULT_EPS.
state: State<(Array, Array)>Inner state
Implementations
Sourceimpl AdaDelta
impl AdaDelta
Sourcepub const DEFAULT_RHO: f32 = 0.9
pub const DEFAULT_RHO: f32 = 0.9
Default value for rho, matching Python MLX.
Sourcepub const DEFAULT_EPS: f32 = 1e-6
pub const DEFAULT_EPS: f32 = 1e-6
Default value for eps