pub struct AdaGrad {
pub lr: Array,
pub eps: Array,
pub state: State,
}Expand description
The Adagrad optimizer.
Please refer to the original paper for more details:
[1]: Duchi, J., Hazan, E. and Singer, Y., 2011. Adaptive subgradient methods for online learning and stochastic optimization. JMLR 2011.
Fields
lr: ArrayLearning rate
eps: ArrayThe epsilon added to the denominator to improve numerical stability. Default to
AdaGrad::DEFAULT_EPS.
state: StateInner state
Implementations