pub struct Adafactor {
pub lr: Option<f32>,
pub eps: (Array, Array),
pub clip_threshold: Array,
pub decay_rate: Array,
pub beta1: AdafactorBeta1,
pub weight_decay: f32,
pub scale_parameter: bool,
pub relative_step: bool,
pub warmup_init: bool,
pub state: State<AdafactorState>,
}Expand description
The Adafactor optimizer.
Our Adafactor implementation follows the original paper: `Adafactor: Adaptive Learning Rates with Sublinear Memory Cost https://arxiv.org/abs/1804.04235
Fields
lr: Option<f32>The learning rate.
eps: (Array, Array)The first term is added to the square of the gradients to improve numerical stability.
Default to Adafactor::DEFAULT_EPS.
clip_threshold: ArrayClips the unscaled update. Default to Adafactor::DEFAULT_CLIP_THRESHOLD.
decay_rate: ArrayCoefficient for the running average of the squared gradient. Default to
Adafactor::DEFAULT_DECAY_RATE.
beta1: AdafactorBeta1If set then the first moment will be used.
weight_decay: f32The weight decay. Default to Adafactor::DEFAULT_WEIGHT_DECAY.
scale_parameter: boolIf true the learningRate will be scaled by max(eps.0, RMS(parameter)). Default to
Adafactor::DEFAULT_SCALE_PARAMETER.
relative_step: boolIf true the learningRate will be ignored and the relative step size will be
computed. Default to Adafactor::DEFAULT_RELATIVE_STEP.
warmup_init: boolIf true the relative step size will be calculated by the current step. Default to
Adafactor::DEFAULT_WARMUP_INIT.
state: State<AdafactorState>Inner state.
Implementations
Sourceimpl Adafactor
impl Adafactor
Sourcepub const DEFAULT_LR: Option<f32> = None
pub const DEFAULT_LR: Option<f32> = None
Default value for lr
Sourcepub const DEFAULT_EPS: (f32, f32)
pub const DEFAULT_EPS: (f32, f32)
Default values for eps
Sourcepub const DEFAULT_CLIP_THRESHOLD: f32 = 1.0
pub const DEFAULT_CLIP_THRESHOLD: f32 = 1.0
Default value for clip_threshold
Sourcepub const DEFAULT_DECAY_RATE: f32 = -0.8
pub const DEFAULT_DECAY_RATE: f32 = -0.8
Default value for decay_rate
Sourcepub const DEFAULT_WEIGHT_DECAY: f32 = 0.0
pub const DEFAULT_WEIGHT_DECAY: f32 = 0.0
Default value for weight_decay
Sourcepub const DEFAULT_SCALE_PARAMETER: bool = true
pub const DEFAULT_SCALE_PARAMETER: bool = true
Default value for scale_parameter
Sourcepub const DEFAULT_RELATIVE_STEP: bool = true
pub const DEFAULT_RELATIVE_STEP: bool = true
Default value for relative_step
Sourcepub const DEFAULT_WARMUP_INIT: bool = false
pub const DEFAULT_WARMUP_INIT: bool = false
Default value for warmup_init
Sourcepub const DEFAULT_BETA1: Option<f32> = None
pub const DEFAULT_BETA1: Option<f32> = None
Default value for beta1