pub struct Adam {
pub lr: Array,
pub betas: (Array, Array),
pub eps: Array,
pub state: State<(Array, Array)>,
}Expand description
The Adam optimizer.
Please refer to the original paper for more details:
[1]: Kingma, D.P. and Ba, J., 2015. Adam: A method for stochastic optimization. ICLR 2015.
Fields
lr: ArrayThe learning rate
betas: (Array, Array)The coefficients used for computing running averages of the gradient and its square
Default to Adam::DEFAULT_BETAS
eps: ArrayThe epsilon added to the denominator to improve numerical stability
Default to Adam::DEFAULT_EPS
state: State<(Array, Array)>Inner state
Implementations
Sourceimpl Adam
impl Adam
Sourcepub const DEFAULT_BETAS: (f32, f32)
pub const DEFAULT_BETAS: (f32, f32)
Default values for betas
Sourcepub const DEFAULT_EPS: f32 = 1e-8
pub const DEFAULT_EPS: f32 = 1e-8
Default value for eps