pub struct Adamax {
pub lr: Array,
pub betas: (Array, Array),
pub eps: Array,
pub state: State<(Array, Array)>,
}Expand description
The Adamax optimizer, a variant of Adam based on the infinity norm [1].
Our Adam implementation follows the original paper and omits the bias correction in the first and second moment estimates. In detail,
[1]: Kingma, D.P. and Ba, J., 2015. Adam: A method for stochastic optimization. ICLR 2015.
Fields
lr: ArrayThe learning rate.
betas: (Array, Array)The beta coefficients
eps: ArrayThe epsilon added to the denominator to improve numerical stability.
state: State<(Array, Array)>Inner state.
Implementations
Sourceimpl Adamax
impl Adamax
Sourcepub const DEFAULT_BETAS: (f32, f32)
pub const DEFAULT_BETAS: (f32, f32)
Default value for betas.
Sourcepub const DEFAULT_EPS: f32 = 1e-8
pub const DEFAULT_EPS: f32 = 1e-8
Default value for eps.