pub struct Lion {
pub lr: f32,
pub betas: (Array, Array),
pub weight_decay: f32,
pub state: State,
}Expand description
The Lion optimizer [1].
Since updates are computed through the sign operation, they tend to have larger norm than for other optimizers such as SGD and Adam. We recommend a learning rate that is 3-10x smaller than AdamW and a weight decay 3-10x larger than AdamW to maintain the strength `(lr
- wd)`. Our Lion implementation follows the original paper. In detail,
[1]: Chen, X. Symbolic Discovery of Optimization Algorithms. arXiv preprint arXiv:2302.06675.
Fields
lr: f32The learning rate.
betas: (Array, Array)The coefficients used for computing running averages of the gradient and its square.
Default to Lion::DEFAULT_BETAS.
weight_decay: f32The weight decay. Default to Lion::DEFAULT_WEIGHT_DECAY.
state: StateInner state.
Implementations
Sourceimpl Lion
impl Lion
Sourcepub const DEFAULT_BETAS: (f32, f32)
pub const DEFAULT_BETAS: (f32, f32)
Default values for betas
Sourcepub const DEFAULT_WEIGHT_DECAY: f32 = 0.0
pub const DEFAULT_WEIGHT_DECAY: f32 = 0.0
Default value for weight_decay